/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright held by original author
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Application
    rasInterDyMFoam

Description
    Solver for 2 incompressible fluids capturing the interface with
    dynamic mesh motion.  Turbulence is modelled using a runtime selectable
    incompressible RAS model.

Author
    Hrvoje Jasak, Wikki Ltd.  All rights reserved.

\*---------------------------------------------------------------------------*/

#include "fvCFD.H"
#include "dynamicFvMesh.H"
#include "interfaceProperties.H"
#include "twoPhaseMixture.H"
#include "incompressible/turbulenceModel/turbulenceModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

int main(int argc, char *argv[])
{

#   include "setRootCase.H"
#   include "createTime.H"
#   include "createDynamicFvMesh.H"
#   include "readEnvironmentalProperties.H"
#   include "readPISOControls.H"
#   include "initContinuityErrs.H"
#   include "initTotalVolume.H"
#   include "createFields.H"
#   include "readTimeControls.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

    // Execute function objects
    runTime.functionObjects().execute();

    // Update mesh to starting position
//     mesh.update();

    Info<< "\nStarting time loop\n" << endl;

    while (runTime.run())
    {
#       include "readPISOControls.H"
#       include "readTimeControls.H"
#       include "CourantNo.H"

#       include "checkTotalVolume.H"
#       include "setDeltaT.H"

        runTime++;

        Info<< "Time = " << runTime.timeName() << nl << endl;

        // Mesh motion update
        mesh.update();

        for (label ocorr = 1; ocorr <= nOuterCorr; ocorr++)
        {
            // Mesh motion update
            mesh.update();

            ghf = (g & mesh.Cf());

#           include "volContinuity.H"

            twoPhaseProperties.correct();

#           include "UEqn.H"

            // --- PISO loop
            for (int corr=0; corr < nCorr; corr++)
            {
#               include "pdEqn.H"
            }

#           include "limitU.H"

            if (mesh.moving())
            {
                // Make the fluxes relative
                phi -= fvc::meshPhi(rho, U);
                rhoPhi = phi*fvc::interpolate(rho);
            }

#           include "movingMeshRhoUContinuityErrs.H"

            // Calculate static pressure
#           include "pEqn.H"

#           include "gammaEqn.H"

            turbulence->correct();
        }

        runTime.write();

        Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
            << "  ClockTime = " << runTime.elapsedClockTime() << " s"
            << nl << endl;
    }

    Info<< "End\n" << endl;

    return(0);
}


// ************************************************************************* //
